@@ -6,7 +6,7 @@ pub const DEFAULT_ENABLE_UPPER: bool = true;
 pub const DEFAULT_PASS_LEN: usize = 16;
 pub const DEFAULT_PRINT_HELP: bool = false;
 pub const ESTIMATED_ALPHABET_CAPACITY: usize = 76;
-pub const MAX_CONCERGENCE_ITERATIONS: usize = 50000;
+pub const MAX_CONVERGENCE_ITERATIONS: usize = 150000;
 
 pub const SPECIAL_CHARS: [char; 14] = [
     '!', '#', '$', '%', '&', '*', ']', '[', '(', ')', '{', '}', '+', '-',
